from pathlib import Path
from typing import List

from sh.contrib import git


def list_changed_files() -> List[str]:
    """Files changed against origin/master."""
    return list(
        filter(
            bool,
            git.diff(
                '--name-only',
                'origin/master',
            ).stdout.decode().split('\n'),
        ),
    )


def changed_and_existing_files(paths: List[str]) -> List[str]:
    """Files that are in diff and exist."""
    return [
        path
        for path in paths
        if (Path.cwd() / path).exists()
    ]



from pathlib import Path
from typing import Iterable, Tuple, Union

from jeeves_yeti_pyproject.files_and_directories import python_packages

CLIValue = Union[str, int, Path]
CLIParameter = Union[str, Tuple[str, CLIValue]]


LINE_LENGTH = 80


def construct_pytest_args() -> Iterable[str]:   # noqa: WPS213
    """
    Args for pytest.

    # FIXME:
    #   title: Replace `construct_pytest_args` with an overridable config
    #   description: Arguments for pytest are hardcoded. A few of them are
    #   generated and will stay that way, but at least partially we should be
    #   able to override the arguments.
    """
    yield '--strict-markers'
    yield '--strict-config'
    yield '--tb=short'
    yield '--doctest-modules'
    yield '--cov={}'.format(
        ','.join(
            map(str, python_packages()),
        ),
    )
    yield '--cov-report=term:skip-covered'
    yield '--cov-report=html'
    yield '--cov-report=xml'
    yield '--cov-branch'
    yield '--cov-fail-under=100'


def construct_isort_args() -> Iterable[CLIParameter]:
    """
    Isort configuration.

    https://github.com/timothycrosley/isort/wiki/isort-Settings
    See https://github.com/timothycrosley/isort#multi-line-output-modes

    Source: wemake-python-styleguide.
    """
    yield '--trailing-comma'
    yield '--use-parentheses'
    yield '--multi-line', 'VERTICAL_HANGING_INDENT'
    yield '--line-length', LINE_LENGTH



from pathlib import Path
from typing import List


def directories_with_a_file_in_them(pattern: str) -> List[Path]:
    """All subdirectories which have a file in them conforming to a pattern."""
    return [
        sub_directory
        for sub_directory in Path.cwd().iterdir()
        if sub_directory.is_dir() and list(sub_directory.glob(pattern))
    ]


def python_directories() -> List[Path]:
    """All subdirectories of the current directory with Python files."""
    return directories_with_a_file_in_them('*.py')


def python_packages() -> List[Path]:
    """All Python packages in current directory."""
    return directories_with_a_file_in_them('__init__.py')



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['jeeves_yeti_pyproject', 'jeeves_yeti_pyproject.flakeheaven']

package_data = \
{'': ['*']}

install_requires = \
['add-trailing-comma>=2.4.0,<3.0.0',
 'flakeheaven>=3.2.1,<4.0.0',
 'jeeves-shell>=2.1.0,<3.0.0',
 'mkdocs-iolanta>=0.1.0,<0.2.0',
 'mkdocs-macros-plugin>=0.7.0,<0.8.0',
 'mkdocs-material>=9.0.3,<10.0.0',
 'mkdocs>=1.4.2,<2.0.0',
 'mypy>=0.910,<0.911',
 'pytest-cov>=2.12,<3.0',
 'pytest-randomly>=3.8,<4.0',
 'pytest>=6.2,<7.0',
 'rich>=13.3.1,<14.0.0',
 'safety>=1.10,<2.0',
 'sh>=1.14.3,<2.0.0',
 'tomlkit>=0.11.6,<0.12.0',
 'wemake-python-styleguide>=0.17.0,<0.18.0']

entry_points = \
{'jeeves': ['pyproject = jeeves_yeti_pyproject:jeeves']}

setup_kwargs = {
    'name': 'jeeves-yeti-pyproject',
    'version': '0.2.11',
    'description': 'Opinionated Jeeves plugin for Python projects.',
    'long_description': '# jeeves-yeti-pyproject\n\n',
    'author': 'Anatoly Scherbakov',
    'author_email': 'altaisoft@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
